"""# Awesome Streamlit Package.

This package is **highly experimental**!

- It provides functionality that has not yet or never will be provided
by the streamlit package.
- It provides functionality needed for the Awesome Streamlit Application
that you might also find valuable.
- The api might change dramatically and often.
  - If the streamlit package provides the functionality, then it will be removed from this package.
- If you find a version that works for you, then please **pin the version number**!

You can install it using

```bash
pip install awesome-streamlit
```

You can use it using

```python
import awesome_streamlit as ast

ast.experiments.write_hello_world()
```

or alternatively if you just need the experimental features

```python
from awesome_streamlit import experiments as ste

ste.write_hello_world()
```

and the result should look like ![Awesome Streamlit Gallery](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)

For more information please visit the [Awesome Streamlit Project](https://github.com/MarcSkovMadsen/awesome-streamlit) on GitHub.
